ArenaSlice

Struct ArenaSlice 

pub struct ArenaSlice<T> { /* private fields */ }
Interning arena for slices of type T.

Implementations

Source

impl<T> ArenaSlice<T>

pub fn with_capacity(slices: usize, items: usize) -> Self

Creates a new arena with pre-allocated space to store at least the given number of slices, totalling the given number of items of type T.

pub fn slices(&self) -> usize

Returns the number of slices in this arena.

Note that because ArenaSlice is a concurrent data structure, this is only a snapshot as viewed by this thread, and the result may change if other threads are inserting values.

pub fn items(&self) -> usize

Returns the total number of items of type T in this arena.

Note that because ArenaSlice is a concurrent data structure, this is only a snapshot as viewed by this thread, and the result may change if other threads are inserting values.

pub fn is_empty(&self) -> bool

Checks if this arena is empty.

Note that because ArenaSlice is a concurrent data structure, this is only a snapshot as viewed by this thread, and the result may change if other threads are inserting values.

Source

impl<T> ArenaSlice<T>
where T: Eq + Hash,

pub fn find(&self, value: &[T]) -> Option<InternedSlice<T>>

Returns the given value’s InternedSlice handle if it is already interned.

Otherwise, this simply returns None without adding the value to this arena.

Source

impl<T> ArenaSlice<T>
where T: GetSize,

pub fn print_summary(&self, prefix: &str, title: &str, total_bytes: usize)

Available on crate feature debug only.

Prints a summary of the storage used by this arena to stdout.

Source

impl<T> ArenaSlice<T>
where T: Default + Eq + Hash,

pub fn intern_owned(&self, value: Vec<T>) -> InternedSlice<T>

Interns the given value in this arena.

If the value was already interned in this arena, its interning index will simply be returned. Otherwise it will be stored into the arena.

pub fn intern_array<const N: usize>(&self, value: [T; N]) -> InternedSlice<T>

Interns the given value in this arena.

If the value was already interned in this arena, its interning index will simply be returned. Otherwise it will be stored into the arena.

pub fn push_owned_mut(&mut self, value: Vec<T>) -> InternedSlice<T>

Available on crate feature raw only.

Unconditionally push a value, without validating that it’s already interned.

pub fn push_array_mut<const N: usize>( &mut self, value: [T; N], ) -> InternedSlice<T>

Available on crate feature raw only.

Unconditionally push a value, without validating that it’s already interned.

Source

impl<T> ArenaSlice<T>
where T: Default + Clone + Eq + Hash,

pub fn intern(&self, value: &[T]) -> InternedSlice<T>

Interns the given value in this arena.

If the value was already interned in this arena, its interning index will simply be returned. Otherwise it will be stored into the arena.

If T is Copy, it may be more efficient to call intern_copy() instead.

pub fn push_mut(&mut self, value: &[T]) -> u32

Available on crate feature raw only.

Unconditionally push a value, without validating that it’s already interned.

If T is Copy, calling push_copy_mut() may be more efficient.

Source

impl<T> ArenaSlice<T>
where T: Default + Copy + Eq + Hash,

pub fn intern_copy(&self, value: &[T]) -> InternedSlice<T>

Interns the given value in this arena.

If the value was already interned in this arena, its interning index will simply be returned. Otherwise it will be stored into the arena.

If T is only Clone, you can call intern() instead. If T is also not Clone, you can call intern_owned() or intern_array().

pub fn push_copy_mut(&mut self, value: &[T]) -> u32

Available on crate feature raw only.

Unconditionally push a value, without validating that it’s already interned.

If T is only Clone, you can call push_mut() instead.

Source

impl<T> ArenaSlice<T>

pub fn lookup(&self, interned: InternedSlice<T>) -> &[T]

Retrieves the given InternedSlice value from this arena.

The caller is responsible for ensuring that the same arena was used to intern this value, otherwise an arbitrary value will be returned or a panic will happen.