ForwardMapping

Struct ForwardMapping 

pub struct ForwardMapping(/* private fields */);
A mapping to re-order items in an Arena, ArenaSlice or ArenaStr.

Implementations

Source

impl ForwardMapping

pub fn identity(count: u32) -> Self

Creates a new identity mapping with the given number of items.

pub fn is_identity(&self) -> bool

Checks wether this mapping is the identity.

pub fn map<T: ?Sized, Storage>( &self, index: Interned<T, Storage>, ) -> Interned<T, Storage>

Maps the given interned handle to a handle for the re-ordered arena.

pub fn map_slice<T>(&self, index: InternedSlice<T>) -> InternedSlice<T>

Maps the given interned handle to a handle for the re-ordered arena.

pub fn map_str(&self, index: InternedStr) -> InternedStr

Maps the given interned handle to a handle for the re-ordered arena.

pub fn compose(self, other: Self) -> Self

Returned a composition of this mapping followed by the other mapping.

The composition is such that for any interned handle index, map1.compose(map2).map(index) is equal to map2.map(map1.map(index)).

pub fn count_remapped(&self) -> usize

Available on crate feature debug only.

Returns the number of items that are remapped by this mapping.