Arena

Struct Arena 

pub struct Arena<T: ?Sized, Storage = T> { /* private fields */ }
Interning arena for values of type T, storing them with the given Storage type (that needs to be Sized).

For Sized values, Storage = T is a good default that incurs no overhead. For non-Sized values such as [str], you need to specify a Sized storage type, such as Box<T>.

Implementations

Source

impl<T: ?Sized, Storage> Arena<T, Storage>

pub fn with_capacity(len: usize) -> Self

Creates a new arena with pre-allocated space to store at least len values of type T.

pub fn len(&self) -> usize

Returns the number of values in this arena.

Note that because Arena is a concurrent data structure, this is only a snapshot as viewed by this thread, and the result may change if other threads are inserting values.

pub fn is_empty(&self) -> bool

Checks if this arena is empty.

Note that because Arena is a concurrent data structure, this is only a snapshot as viewed by this thread, and the result may change if other threads are inserting values.

Source

impl<T, Storage> Arena<T, Storage>
where T: Eq + Hash + ?Sized, Storage: Borrow<T>,

pub fn find(&self, value: &T) -> Option<Interned<T, Storage>>

Returns the given value’s Interned handle if it is already interned.

Otherwise, this simply returns None without adding the value to this arena.

Source

impl<T, Storage> Arena<T, Storage>
where T: Eq + Hash + ?Sized, Storage: Borrow<T>,

pub fn push_mut(&mut self, value: Storage) -> u32

Available on crate feature raw only.

Unconditionally push a value, without validating that it’s already interned.

Source

impl<T: ?Sized, Storage> Arena<T, Storage>
where Storage: GetSize,

pub fn print_summary(&self, prefix: &str, title: &str, total_bytes: usize)

Available on crate feature debug only.

Prints a summary of the storage used by this arena to stdout.

Source

impl<T, Storage> Arena<T, Storage>
where T: Eq + Hash + ?Sized, Storage: Borrow<T>,

pub fn intern( &self, value: impl Borrow<T> + Into<Storage>, ) -> Interned<T, Storage>

Interns the given value in this arena.

If the value was already interned in this arena, it will simply be borrowed to retrieve its interning index. Otherwise it will then be converted to store it into the arena.

Source

impl<T: ?Sized, Storage> Arena<T, Storage>
where Storage: Clone,

pub fn lookup(&self, interned: Interned<T, Storage>) -> Storage

Retrieves the given Interned value from this arena.

The caller is responsible for ensuring that the same arena was used to intern this value, otherwise an arbitrary value will be returned or a panic will happen.

See also lookup_ref() if you only need a reference.

Source

impl<T: ?Sized, Storage> Arena<T, Storage>
where Storage: Borrow<T>,

pub fn lookup_ref(&self, interned: Interned<T, Storage>) -> &T

Retrieves a reference to the given Interned value from this arena.

The caller is responsible for ensuring that the same arena was used to intern this value, otherwise an arbitrary value will be returned or a panic will happen.

See also lookup() if you need an owned value.