pub struct Arena<T: ?Sized, Storage = T> { /* private fields */ }Expand description
Implementations
Sourceimpl<T, Storage> Arena<T, Storage>
impl<T, Storage> Arena<T, Storage>
Sourcepub fn map(&self, mapping: &ReverseMapping) -> Self
pub fn map(&self, mapping: &ReverseMapping) -> Self
Returns a re-ordered version of this arena based on the given mapping.
Sourceimpl<T: ?Sized, Storage> Arena<T, Storage>
impl<T: ?Sized, Storage> Arena<T, Storage>
Sourcepub fn with_capacity(len: usize) -> Self
pub fn with_capacity(len: usize) -> Self
Creates a new arena with pre-allocated space to store at least len
values of type T.
Sourceimpl<T: ?Sized, Storage> Arena<T, Storage>where
Storage: GetSize,
impl<T: ?Sized, Storage> Arena<T, Storage>where
Storage: GetSize,
Sourcepub fn print_summary(&self, prefix: &str, title: &str, total_bytes: usize)
Available on crate feature debug only.
pub fn print_summary(&self, prefix: &str, title: &str, total_bytes: usize)
debug only.Prints a summary of the storage used by this arena to stdout.
Sourceimpl<T, Storage> Arena<T, Storage>
impl<T, Storage> Arena<T, Storage>
Sourcepub fn intern(
&self,
value: impl Borrow<T> + Into<Storage>,
) -> Interned<T, Storage>
pub fn intern( &self, value: impl Borrow<T> + Into<Storage>, ) -> Interned<T, Storage>
Interns the given value in this arena.
If the value was already interned in this arena, it will simply be borrowed to retrieve its interning index. Otherwise it will then be converted to store it into the arena.
See also intern_mut(), which is more efficient if
you hold a mutable reference to this arena as it avoids acquiring locks.
Sourcepub fn intern_mut(
&mut self,
value: impl Borrow<T> + Into<Storage>,
) -> Interned<T, Storage>
pub fn intern_mut( &mut self, value: impl Borrow<T> + Into<Storage>, ) -> Interned<T, Storage>
Interns the given value in this arena.
If the value was already interned in this arena, it will simply be borrowed to retrieve its interning index. Otherwise it will then be converted to store it into the arena.
Contrary to intern(), no locks are held internally
because this function already takes an exclusive mutable reference to
this arena.
Sourceimpl<T: ?Sized, Storage> Arena<T, Storage>where
Storage: Clone,
impl<T: ?Sized, Storage> Arena<T, Storage>where
Storage: Clone,
Sourcepub fn lookup(&self, interned: Interned<T, Storage>) -> Storage
pub fn lookup(&self, interned: Interned<T, Storage>) -> Storage
Retrieves the given Interned value from this arena.
The caller is responsible for ensuring that the same arena was used to intern this value, otherwise an arbitrary value will be returned or a panic will happen.
See also lookup_ref() if you only need a
reference.