pub struct ArenaSlice<T> { /* private fields */ }Expand description
Interning arena for slices of type T.
Implementations
Sourceimpl<T> ArenaSlice<T>
impl<T> ArenaSlice<T>
Sourcepub fn with_capacity(slices: usize, items: usize) -> Self
pub fn with_capacity(slices: usize, items: usize) -> Self
Creates a new arena with pre-allocated space to store at least the given
number of slices, totalling the given number of items of type T.
Sourcepub fn slices(&self) -> usize
pub fn slices(&self) -> usize
Returns the number of slices in this arena.
Note that because ArenaSlice is a concurrent data structure, this is
only a snapshot as viewed by this thread, and the result may change
if other threads are inserting values.
Sourcepub fn items(&self) -> usize
pub fn items(&self) -> usize
Returns the total number of items of type T in this arena.
Note that because ArenaSlice is a concurrent data structure, this is
only a snapshot as viewed by this thread, and the result may change
if other threads are inserting values.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Checks if this arena is empty.
Note that because ArenaSlice is a concurrent data structure, this is
only a snapshot as viewed by this thread, and the result may change
if other threads are inserting values.
Sourceimpl<T> ArenaSlice<T>
impl<T> ArenaSlice<T>
Sourcepub fn find(&self, value: &[T]) -> Option<InternedSlice<T>>
pub fn find(&self, value: &[T]) -> Option<InternedSlice<T>>
Returns the given value’s InternedSlice handle if it is already
interned.
Otherwise, this simply returns None without adding the value to this
arena.
Sourceimpl<T> ArenaSlice<T>where
T: GetSize,
impl<T> ArenaSlice<T>where
T: GetSize,
Sourcepub fn print_summary(&self, prefix: &str, title: &str, total_bytes: usize)
Available on crate feature debug only.
pub fn print_summary(&self, prefix: &str, title: &str, total_bytes: usize)
debug only.Prints a summary of the storage used by this arena to stdout.
Sourceimpl<T> ArenaSlice<T>
impl<T> ArenaSlice<T>
Sourcepub fn intern_owned(&self, value: Vec<T>) -> InternedSlice<T>
pub fn intern_owned(&self, value: Vec<T>) -> InternedSlice<T>
Interns the given value in this arena.
If the value was already interned in this arena, its interning index will simply be returned. Otherwise it will be stored into the arena.
Sourcepub fn intern_array<const N: usize>(&self, value: [T; N]) -> InternedSlice<T>
pub fn intern_array<const N: usize>(&self, value: [T; N]) -> InternedSlice<T>
Interns the given value in this arena.
If the value was already interned in this arena, its interning index will simply be returned. Otherwise it will be stored into the arena.
Sourcepub fn push_owned_mut(&mut self, value: Vec<T>) -> InternedSlice<T>
Available on crate feature raw only.
pub fn push_owned_mut(&mut self, value: Vec<T>) -> InternedSlice<T>
raw only.Unconditionally push a value, without validating that it’s already interned.
Sourcepub fn push_array_mut<const N: usize>(
&mut self,
value: [T; N],
) -> InternedSlice<T>
Available on crate feature raw only.
pub fn push_array_mut<const N: usize>( &mut self, value: [T; N], ) -> InternedSlice<T>
raw only.Unconditionally push a value, without validating that it’s already interned.
Sourceimpl<T> ArenaSlice<T>
impl<T> ArenaSlice<T>
Sourcepub fn intern(&self, value: &[T]) -> InternedSlice<T>
pub fn intern(&self, value: &[T]) -> InternedSlice<T>
Interns the given value in this arena.
If the value was already interned in this arena, its interning index will simply be returned. Otherwise it will be stored into the arena.
If T is Copy, it may be more efficient to call
intern_copy() instead.
Sourceimpl<T> ArenaSlice<T>
impl<T> ArenaSlice<T>
Sourcepub fn intern_copy(&self, value: &[T]) -> InternedSlice<T>
pub fn intern_copy(&self, value: &[T]) -> InternedSlice<T>
Interns the given value in this arena.
If the value was already interned in this arena, its interning index will simply be returned. Otherwise it will be stored into the arena.
If T is only Clone, you can call intern()
instead. If T is also not Clone, you can call
intern_owned() or
intern_array().
Sourcepub fn push_copy_mut(&mut self, value: &[T]) -> u32
Available on crate feature raw only.
pub fn push_copy_mut(&mut self, value: &[T]) -> u32
raw only.Unconditionally push a value, without validating that it’s already interned.
If T is only Clone, you can call push_mut()
instead.
Sourceimpl<T> ArenaSlice<T>
impl<T> ArenaSlice<T>
Sourcepub fn lookup(&self, interned: InternedSlice<T>) -> &[T]
pub fn lookup(&self, interned: InternedSlice<T>) -> &[T]
Retrieves the given InternedSlice value from this arena.
The caller is responsible for ensuring that the same arena was used to intern this value, otherwise an arbitrary value will be returned or a panic will happen.